# Sopel OSD

Sopel OSD is a "niche" method of displaying text in a Sopel bot

# This code is bad, and the author doesn't feel bad
use at your own risk

# Installation
````
git clone https://github.com/deathbybandaid/Sopel-OSD.git
cd Sopel-OSD
pip3 install .
````
